tsplib95 package
================

Submodules
----------

tsplib95.cli module
-------------------

.. automodule:: tsplib95.cli
    :members:
    :undoc-members:
    :show-inheritance:

tsplib95.distances module
-------------------------

.. automodule:: tsplib95.distances
    :members:
    :undoc-members:
    :show-inheritance:

tsplib95.matrix module
----------------------

.. automodule:: tsplib95.matrix
    :members:
    :undoc-members:
    :show-inheritance:

tsplib95.models module
----------------------

.. automodule:: tsplib95.models
    :members:
    :undoc-members:
    :show-inheritance:

tsplib95.parser module
----------------------

.. automodule:: tsplib95.parser
    :members:
    :undoc-members:
    :show-inheritance:

tsplib95.utils module
---------------------

.. automodule:: tsplib95.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: tsplib95
    :members:
    :undoc-members:
    :show-inheritance:
